# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.cloud.aiplatform_v1beta1.types import content as gca_content
from google.cloud.aiplatform_v1beta1.types import memory_bank
from google.cloud.aiplatform_v1beta1.types import operation
from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.aiplatform.v1beta1",
    manifest={
        "CreateMemoryRequest",
        "CreateMemoryOperationMetadata",
        "GetMemoryRequest",
        "UpdateMemoryRequest",
        "UpdateMemoryOperationMetadata",
        "ListMemoriesRequest",
        "ListMemoriesResponse",
        "DeleteMemoryRequest",
        "DeleteMemoryOperationMetadata",
        "GenerateMemoriesRequest",
        "GenerateMemoriesResponse",
        "GenerateMemoriesOperationMetadata",
        "RetrieveMemoriesRequest",
        "RetrieveMemoriesResponse",
    },
)


class CreateMemoryRequest(proto.Message):
    r"""Request message for
    [MemoryBankService.CreateMemory][google.cloud.aiplatform.v1beta1.MemoryBankService.CreateMemory].

    Attributes:
        parent (str):
            Required. The resource name of the ReasoningEngine to create
            the Memory under. Format:
            ``projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}``
        memory (google.cloud.aiplatform_v1beta1.types.Memory):
            Required. The Memory to be created.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    memory: memory_bank.Memory = proto.Field(
        proto.MESSAGE,
        number=2,
        message=memory_bank.Memory,
    )


class CreateMemoryOperationMetadata(proto.Message):
    r"""Details of
    [MemoryBankService.CreateMemory][google.cloud.aiplatform.v1beta1.MemoryBankService.CreateMemory]
    operation.

    Attributes:
        generic_metadata (google.cloud.aiplatform_v1beta1.types.GenericOperationMetadata):
            The common part of the operation metadata.
    """

    generic_metadata: operation.GenericOperationMetadata = proto.Field(
        proto.MESSAGE,
        number=1,
        message=operation.GenericOperationMetadata,
    )


class GetMemoryRequest(proto.Message):
    r"""Request message for
    [MemoryBankService.GetMemory][google.cloud.aiplatform.v1beta1.MemoryBankService.GetMemory].

    Attributes:
        name (str):
            Required. The resource name of the Memory. Format:
            ``projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/memories/{memory}``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateMemoryRequest(proto.Message):
    r"""Request message for
    [MemoryBankService.UpdateMemory][google.cloud.aiplatform.v1beta1.MemoryBankService.UpdateMemory].

    Attributes:
        memory (google.cloud.aiplatform_v1beta1.types.Memory):
            Required. The Memory which replaces the
            resource on the server.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Optional. Mask specifying which fields to update. Supported
            fields:

            ::

               * `display_name`
               * `description`
               * `fact`
    """

    memory: memory_bank.Memory = proto.Field(
        proto.MESSAGE,
        number=1,
        message=memory_bank.Memory,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class UpdateMemoryOperationMetadata(proto.Message):
    r"""Details of
    [MemoryBankService.UpdateMemory][google.cloud.aiplatform.v1beta1.MemoryBankService.UpdateMemory]
    operation.

    Attributes:
        generic_metadata (google.cloud.aiplatform_v1beta1.types.GenericOperationMetadata):
            The common part of the operation metadata.
    """

    generic_metadata: operation.GenericOperationMetadata = proto.Field(
        proto.MESSAGE,
        number=1,
        message=operation.GenericOperationMetadata,
    )


class ListMemoriesRequest(proto.Message):
    r"""Request message for
    [MemoryBankService.ListMemories][google.cloud.aiplatform.v1beta1.MemoryBankService.ListMemories].

    Attributes:
        parent (str):
            Required. The resource name of the ReasoningEngine to list
            the Memories under. Format:
            ``projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}``
        filter (str):
            Optional. The standard list filter. More detail in
            `AIP-160 <https://google.aip.dev/160>`__.

            Supported fields (equality match only):

            - ``scope`` (as a JSON string)
        page_size (int):
            Optional. The standard list page size.
        page_token (str):
            Optional. The standard list page token.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=2,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=3,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListMemoriesResponse(proto.Message):
    r"""Response message for
    [MemoryBankService.ListMemories][google.cloud.aiplatform.v1beta1.MemoryBankService.ListMemories].

    Attributes:
        memories (MutableSequence[google.cloud.aiplatform_v1beta1.types.Memory]):
            List of Memories in the requested page.
        next_page_token (str):
            A token to retrieve the next page of results. Pass to
            [ListMemoriesRequest.page_token][google.cloud.aiplatform.v1beta1.ListMemoriesRequest.page_token]
            to obtain that page.
    """

    @property
    def raw_page(self):
        return self

    memories: MutableSequence[memory_bank.Memory] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=memory_bank.Memory,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class DeleteMemoryRequest(proto.Message):
    r"""Request message for
    [MemoryBankService.DeleteMemory][google.cloud.aiplatform.v1beta1.MemoryBankService.DeleteMemory].

    Attributes:
        name (str):
            Required. The resource name of the Memory to delete. Format:
            ``projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/memories/{memory}``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class DeleteMemoryOperationMetadata(proto.Message):
    r"""Details of
    [MemoryBankService.DeleteMemory][google.cloud.aiplatform.v1beta1.MemoryBankService.DeleteMemory]
    operation.

    Attributes:
        generic_metadata (google.cloud.aiplatform_v1beta1.types.GenericOperationMetadata):
            The common part of the operation metadata.
    """

    generic_metadata: operation.GenericOperationMetadata = proto.Field(
        proto.MESSAGE,
        number=1,
        message=operation.GenericOperationMetadata,
    )


class GenerateMemoriesRequest(proto.Message):
    r"""Request message for
    [MemoryBankService.GenerateMemories][google.cloud.aiplatform.v1beta1.MemoryBankService.GenerateMemories].

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        vertex_session_source (google.cloud.aiplatform_v1beta1.types.GenerateMemoriesRequest.VertexSessionSource):
            Defines a Vertex Session as the source
            content from which to generate memories.

            This field is a member of `oneof`_ ``source``.
        direct_contents_source (google.cloud.aiplatform_v1beta1.types.GenerateMemoriesRequest.DirectContentsSource):
            Defines a direct source of content as the
            source content from which to generate memories.

            This field is a member of `oneof`_ ``source``.
        direct_memories_source (google.cloud.aiplatform_v1beta1.types.GenerateMemoriesRequest.DirectMemoriesSource):
            Defines a direct source of memories that should be uploaded
            to Memory Bank. This is similar to ``CreateMemory``, but it
            allows for consolidation between these new memories and
            existing memories for the same scope.

            This field is a member of `oneof`_ ``source``.
        parent (str):
            Required. The resource name of the ReasoningEngine to
            generate memories for. Format:
            ``projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}``
        disable_consolidation (bool):
            Optional. If true, generated memories will
            not be consolidated with existing memories; all
            generated memories will be added as new memories
            regardless of whether they are duplicates of or
            contradictory to existing memories. By default,
            memory consolidation is enabled.
        scope (MutableMapping[str, str]):
            Optional. The scope of the memories that should be
            generated. Memories will be consolidated across memories
            with the same scope. Must be provided unless the scope is
            defined in the source content. If ``scope`` is provided, it
            will override the scope defined in the source content. Scope
            values cannot contain the wildcard character '\*'.
    """

    class VertexSessionSource(proto.Message):
        r"""Defines an Agent Engine Session from which to generate the memories.
        If ``scope`` is not provided, the scope will be extracted from the
        Session (i.e. {"user_id": sesison.user_id}).

        Attributes:
            session (str):
                Required. The resource name of the Session to generate
                memories for. Format:
                ``projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/sessions/{session}``
            start_time (google.protobuf.timestamp_pb2.Timestamp):
                Optional. Time range to define which session
                events should be used to generate memories.
                Start time (inclusive) of the time range. If not
                set, the start time is unbounded.
            end_time (google.protobuf.timestamp_pb2.Timestamp):
                Optional. End time (exclusive) of the time
                range. If not set, the end time is unbounded.
        """

        session: str = proto.Field(
            proto.STRING,
            number=1,
        )
        start_time: timestamp_pb2.Timestamp = proto.Field(
            proto.MESSAGE,
            number=2,
            message=timestamp_pb2.Timestamp,
        )
        end_time: timestamp_pb2.Timestamp = proto.Field(
            proto.MESSAGE,
            number=3,
            message=timestamp_pb2.Timestamp,
        )

    class DirectContentsSource(proto.Message):
        r"""Defines a direct source of content from which to generate the
        memories.

        Attributes:
            events (MutableSequence[google.cloud.aiplatform_v1beta1.types.GenerateMemoriesRequest.DirectContentsSource.Event]):
                Required. The source content (i.e. chat
                history) to generate memories from.
        """

        class Event(proto.Message):
            r"""A single piece of conversation from which to generate
            memories.

            Attributes:
                content (google.cloud.aiplatform_v1beta1.types.Content):
                    Required. A single piece of content from
                    which to generate memories.
            """

            content: gca_content.Content = proto.Field(
                proto.MESSAGE,
                number=1,
                message=gca_content.Content,
            )

        events: MutableSequence[
            "GenerateMemoriesRequest.DirectContentsSource.Event"
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=1,
            message="GenerateMemoriesRequest.DirectContentsSource.Event",
        )

    class DirectMemoriesSource(proto.Message):
        r"""Defines a direct source of memories that should be uploaded
        to Memory Bank with consolidation.

        Attributes:
            direct_memories (MutableSequence[google.cloud.aiplatform_v1beta1.types.GenerateMemoriesRequest.DirectMemoriesSource.DirectMemory]):
                Required. The direct memories to upload to
                Memory Bank. At most 5 direct memories are
                allowed per request.
        """

        class DirectMemory(proto.Message):
            r"""A direct memory to upload to Memory Bank.

            Attributes:
                fact (str):
                    Required. The fact to consolidate with
                    existing memories.
            """

            fact: str = proto.Field(
                proto.STRING,
                number=1,
            )

        direct_memories: MutableSequence[
            "GenerateMemoriesRequest.DirectMemoriesSource.DirectMemory"
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=1,
            message="GenerateMemoriesRequest.DirectMemoriesSource.DirectMemory",
        )

    vertex_session_source: VertexSessionSource = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="source",
        message=VertexSessionSource,
    )
    direct_contents_source: DirectContentsSource = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="source",
        message=DirectContentsSource,
    )
    direct_memories_source: DirectMemoriesSource = proto.Field(
        proto.MESSAGE,
        number=9,
        oneof="source",
        message=DirectMemoriesSource,
    )
    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    disable_consolidation: bool = proto.Field(
        proto.BOOL,
        number=4,
    )
    scope: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=8,
    )


class GenerateMemoriesResponse(proto.Message):
    r"""Response message for
    [MemoryBankService.GenerateMemories][google.cloud.aiplatform.v1beta1.MemoryBankService.GenerateMemories].

    Attributes:
        generated_memories (MutableSequence[google.cloud.aiplatform_v1beta1.types.GenerateMemoriesResponse.GeneratedMemory]):
            The generated memories.
    """

    class GeneratedMemory(proto.Message):
        r"""A memory generated by the operation.

        Attributes:
            memory (google.cloud.aiplatform_v1beta1.types.Memory):
                The generated Memory.
            action (google.cloud.aiplatform_v1beta1.types.GenerateMemoriesResponse.GeneratedMemory.Action):
                The action that was performed on the Memory.
        """

        class Action(proto.Enum):
            r"""Actions that can be performed on a Memory.

            Values:
                ACTION_UNSPECIFIED (0):
                    Action is unspecified.
                CREATED (1):
                    The memory was created.
                UPDATED (2):
                    The memory was updated. The ``fact`` field may not be
                    updated if the existing fact is still accurate.
                DELETED (3):
                    The memory was deleted.
            """

            ACTION_UNSPECIFIED = 0
            CREATED = 1
            UPDATED = 2
            DELETED = 3

        memory: memory_bank.Memory = proto.Field(
            proto.MESSAGE,
            number=1,
            message=memory_bank.Memory,
        )
        action: "GenerateMemoriesResponse.GeneratedMemory.Action" = proto.Field(
            proto.ENUM,
            number=2,
            enum="GenerateMemoriesResponse.GeneratedMemory.Action",
        )

    generated_memories: MutableSequence[GeneratedMemory] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=GeneratedMemory,
    )


class GenerateMemoriesOperationMetadata(proto.Message):
    r"""Details of
    [MemoryBankService.GenerateMemories][google.cloud.aiplatform.v1beta1.MemoryBankService.GenerateMemories]
    operation.

    Attributes:
        generic_metadata (google.cloud.aiplatform_v1beta1.types.GenericOperationMetadata):
            The common part of the operation metadata.
    """

    generic_metadata: operation.GenericOperationMetadata = proto.Field(
        proto.MESSAGE,
        number=1,
        message=operation.GenericOperationMetadata,
    )


class RetrieveMemoriesRequest(proto.Message):
    r"""Request message for
    [MemoryBankService.RetrieveMemories][google.cloud.aiplatform.v1beta1.MemoryBankService.RetrieveMemories].

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        similarity_search_params (google.cloud.aiplatform_v1beta1.types.RetrieveMemoriesRequest.SimilaritySearchParams):
            Parameters for semantic similarity search
            based retrieval.

            This field is a member of `oneof`_ ``retrieval_params``.
        simple_retrieval_params (google.cloud.aiplatform_v1beta1.types.RetrieveMemoriesRequest.SimpleRetrievalParams):
            Parameters for simple (non-similarity search)
            retrieval.

            This field is a member of `oneof`_ ``retrieval_params``.
        parent (str):
            Required. The resource name of the ReasoningEngine to
            retrieve memories from. Format:
            ``projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}``
        scope (MutableMapping[str, str]):
            Required. The scope of the memories to retrieve. A memory
            must have exactly the same scope (``Memory.scope``) as the
            scope provided here to be retrieved (same keys and values).
            Order does not matter, but it is case-sensitive.
    """

    class SimilaritySearchParams(proto.Message):
        r"""Parameters for semantic similarity search based retrieval.

        Attributes:
            search_query (str):
                Required. Query to use for similarity search retrieval. If
                provided, then the parent ReasoningEngine must have
                [ReasoningEngineContextSpec.MemoryBankConfig.SimilaritySearchConfig][google.cloud.aiplatform.v1beta1.ReasoningEngineContextSpec.MemoryBankConfig.SimilaritySearchConfig]
                set.
            top_k (int):
                Optional. The maximum number of memories to
                return. The service may return fewer than this
                value. If unspecified, at most 3 memories will
                be returned. The maximum value is 100; values
                above 100 will be coerced to 100.
        """

        search_query: str = proto.Field(
            proto.STRING,
            number=1,
        )
        top_k: int = proto.Field(
            proto.INT32,
            number=2,
        )

    class SimpleRetrievalParams(proto.Message):
        r"""Parameters for simple (non-similarity search) retrieval.

        Attributes:
            page_size (int):
                Optional. The maximum number of memories to
                return. The service may return fewer than this
                value. If unspecified, at most 3 memories will
                be returned. The maximum value is 100; values
                above 100 will be coerced to 100.
            page_token (str):
                Optional. A page token, received from a previous
                ``RetrieveMemories`` call. Provide this to retrieve the
                subsequent page.
        """

        page_size: int = proto.Field(
            proto.INT32,
            number=1,
        )
        page_token: str = proto.Field(
            proto.STRING,
            number=2,
        )

    similarity_search_params: SimilaritySearchParams = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="retrieval_params",
        message=SimilaritySearchParams,
    )
    simple_retrieval_params: SimpleRetrievalParams = proto.Field(
        proto.MESSAGE,
        number=7,
        oneof="retrieval_params",
        message=SimpleRetrievalParams,
    )
    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    scope: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=8,
    )


class RetrieveMemoriesResponse(proto.Message):
    r"""Response message for
    [MemoryBankService.RetrieveMemories][google.cloud.aiplatform.v1beta1.MemoryBankService.RetrieveMemories].

    Attributes:
        retrieved_memories (MutableSequence[google.cloud.aiplatform_v1beta1.types.RetrieveMemoriesResponse.RetrievedMemory]):
            The retrieved memories.
        next_page_token (str):
            A token that can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages. This token is not set if similarity search was used
            for retrieval.
    """

    class RetrievedMemory(proto.Message):
        r"""A retrieved memory.

        Attributes:
            memory (google.cloud.aiplatform_v1beta1.types.Memory):
                The retrieved Memory.
            distance (float):
                The distance between the query and the
                retrieved Memory. Smaller values indicate more
                similar memories. This is only set if similarity
                search was used for retrieval.
        """

        memory: memory_bank.Memory = proto.Field(
            proto.MESSAGE,
            number=1,
            message=memory_bank.Memory,
        )
        distance: float = proto.Field(
            proto.DOUBLE,
            number=2,
        )

    @property
    def raw_page(self):
        return self

    retrieved_memories: MutableSequence[RetrievedMemory] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=RetrievedMemory,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!


import grpc

from google.iam.v1 import iam_policy_pb2 as google_dot_iam_dot_v1_dot_iam__policy__pb2
from google.iam.v1 import policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2


class IAMPolicyStub(object):
    """## API Overview

    Manages Identity and Access Management (IAM) policies.

    Any implementation of an API that offers access control features
    implements the google.iam.v1.IAMPolicy interface.

    ## Data model

    Access control is applied when a principal (user or service account), takes
    some action on a resource exposed by a service. Resources, identified by
    URI-like names, are the unit of access control specification. Service
    implementations can choose the granularity of access control and the
    supported permissions for their resources.
    For example one database service may allow access control to be
    specified only at the Table level, whereas another might allow access control
    to also be specified at the Column level.

    ## Policy Structure

    See google.iam.v1.Policy

    This is intentionally not a CRUD style API because access control policies
    are created and deleted implicitly with the resources to which they are
    attached.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
          channel: A grpc.Channel.
        """
        self.SetIamPolicy = channel.unary_unary(
            "/google.iam.v1.IAMPolicy/SetIamPolicy",
            request_serializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.SetIamPolicyRequest.SerializeToString,
            response_deserializer=google_dot_iam_dot_v1_dot_policy__pb2.Policy.FromString,
        )
        self.GetIamPolicy = channel.unary_unary(
            "/google.iam.v1.IAMPolicy/GetIamPolicy",
            request_serializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.GetIamPolicyRequest.SerializeToString,
            response_deserializer=google_dot_iam_dot_v1_dot_policy__pb2.Policy.FromString,
        )
        self.TestIamPermissions = channel.unary_unary(
            "/google.iam.v1.IAMPolicy/TestIamPermissions",
            request_serializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.TestIamPermissionsRequest.SerializeToString,
            response_deserializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.TestIamPermissionsResponse.FromString,
        )


class IAMPolicyServicer(object):
    """## API Overview

    Manages Identity and Access Management (IAM) policies.

    Any implementation of an API that offers access control features
    implements the google.iam.v1.IAMPolicy interface.

    ## Data model

    Access control is applied when a principal (user or service account), takes
    some action on a resource exposed by a service. Resources, identified by
    URI-like names, are the unit of access control specification. Service
    implementations can choose the granularity of access control and the
    supported permissions for their resources.
    For example one database service may allow access control to be
    specified only at the Table level, whereas another might allow access control
    to also be specified at the Column level.

    ## Policy Structure

    See google.iam.v1.Policy

    This is intentionally not a CRUD style API because access control policies
    are created and deleted implicitly with the resources to which they are
    attached.
    """

    def SetIamPolicy(self, request, context):
        """Sets the access control policy on the specified resource. Replaces any
        existing policy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetIamPolicy(self, request, context):
        """Gets the access control policy for a resource.
        Returns an empty policy if the resource exists and does not have a policy
        set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TestIamPermissions(self, request, context):
        """Returns permissions that a caller has on the specified resource.
        If the resource does not exist, this will return an empty set of
        permissions, not a NOT_FOUND error.

        Note: This operation is designed to be used for building permission-aware
        UIs and command-line tools, not for authorization checking. This operation
        may "fail open" without warning.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_IAMPolicyServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "SetIamPolicy": grpc.unary_unary_rpc_method_handler(
            servicer.SetIamPolicy,
            request_deserializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.SetIamPolicyRequest.FromString,
            response_serializer=google_dot_iam_dot_v1_dot_policy__pb2.Policy.SerializeToString,
        ),
        "GetIamPolicy": grpc.unary_unary_rpc_method_handler(
            servicer.GetIamPolicy,
            request_deserializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.GetIamPolicyRequest.FromString,
            response_serializer=google_dot_iam_dot_v1_dot_policy__pb2.Policy.SerializeToString,
        ),
        "TestIamPermissions": grpc.unary_unary_rpc_method_handler(
            servicer.TestIamPermissions,
            request_deserializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.TestIamPermissionsRequest.FromString,
            response_serializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.TestIamPermissionsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.iam.v1.IAMPolicy", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-

# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
"""Prompt template for creating prompts with variables."""

import re
from typing import Set

_VARIABLE_NAME_REGEX = r"\{([_a-zA-Z][_a-zA-Z0-9]*)\}"


class PromptTemplate:
    """A prompt template for creating prompts with variables.

    The `PromptTemplate` class allows users to define a template string with
    variables represented in curly braces `{variable}`. The variable
    names cannot contain spaces and must start with a letter or underscore,
    followed by letters, digits, or underscore. These variables can be
    replaced with specific values using the `assemble` method, providing
    flexibility in generating dynamic prompts.

    Usage:

        ```
        template_str = "Hello, {name}! Today is {day}. How are you?"
        prompt_template = PromptTemplate(template_str)
        completed_prompt = prompt_template.assemble(name="John", day="Monday")
        print(completed_prompt)
        ```
    """

    def __init__(self, template: str):
        """Initializes the PromptTemplate with a given template.

        Args:
            template: The template string with variables. Variables should be
              represented in curly braces `{variable}`.
        """
        self.template = str(template)
        self.variables = self._get_variables()

    def _get_variables(self) -> Set[str]:
        """Extracts and return a set of variable names from the template."""
        return set(re.findall(_VARIABLE_NAME_REGEX, self.template))

    def assemble(self, **kwargs) -> "PromptTemplate":
        """Replaces only the provided variables in the template with specific values.

        Args:
            **kwargs: Keyword arguments where keys are placeholder names and values
              are the replacements.

        Returns:
            A new PromptTemplate instance with the updated template string.
        """
        assembled_string = self.template
        for variable_name, value in kwargs.items():
            if variable_name not in self.variables:
                raise ValueError(
                    f"Invalid variable name '{variable_name}'. "
                    f"Valid variables are: {self.variables}"
                )
            placeholder = "{" + variable_name + "}"
            assembled_string = assembled_string.replace(placeholder, str(value))
        return PromptTemplate(assembled_string)

    def __str__(self) -> str:
        """Returns the template string."""
        return self.template

    def __repr__(self) -> str:
        """Returns a string representation of the PromptTemplate."""
        return f"PromptTemplate('{self.template}')"



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.cloud.aiplatform_v1beta1.types import operation
from google.cloud.aiplatform_v1beta1.types import session as gca_session
from google.protobuf import field_mask_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.aiplatform.v1beta1",
    manifest={
        "CreateSessionRequest",
        "CreateSessionOperationMetadata",
        "GetSessionRequest",
        "ListSessionsRequest",
        "ListSessionsResponse",
        "UpdateSessionRequest",
        "DeleteSessionRequest",
        "ListEventsRequest",
        "ListEventsResponse",
        "AppendEventRequest",
        "AppendEventResponse",
    },
)


class CreateSessionRequest(proto.Message):
    r"""Request message for
    [SessionService.CreateSession][google.cloud.aiplatform.v1beta1.SessionService.CreateSession].

    Attributes:
        parent (str):
            Required. The resource name of the location to create the
            session in. Format:
            ``projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}``
        session (google.cloud.aiplatform_v1beta1.types.Session):
            Required. The session to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    session: gca_session.Session = proto.Field(
        proto.MESSAGE,
        number=2,
        message=gca_session.Session,
    )


class CreateSessionOperationMetadata(proto.Message):
    r"""Metadata associated with the
    [SessionService.CreateSession][google.cloud.aiplatform.v1beta1.SessionService.CreateSession]
    operation.

    Attributes:
        generic_metadata (google.cloud.aiplatform_v1beta1.types.GenericOperationMetadata):
            The common part of the operation metadata.
    """

    generic_metadata: operation.GenericOperationMetadata = proto.Field(
        proto.MESSAGE,
        number=1,
        message=operation.GenericOperationMetadata,
    )


class GetSessionRequest(proto.Message):
    r"""Request message for
    [SessionService.GetSession][google.cloud.aiplatform.v1beta1.SessionService.GetSession].

    Attributes:
        name (str):
            Required. The resource name of the session. Format:
            ``projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/sessions/{session}``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListSessionsRequest(proto.Message):
    r"""Request message for
    [SessionService.ListSessions][google.cloud.aiplatform.v1beta1.SessionService.ListSessions].

    Attributes:
        parent (str):
            Required. The resource name of the location to list sessions
            from. Format:
            ``projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}``
        page_size (int):
            Optional. The maximum number of sessions to
            return. The service may return fewer than this
            value. If unspecified, at most 100 sessions will
            be returned.
        page_token (str):
            Optional. The
            [next_page_token][google.cloud.aiplatform.v1beta1.ListSessionsResponse.next_page_token]
            value returned from a previous list
            [SessionService.ListSessions][google.cloud.aiplatform.v1beta1.SessionService.ListSessions]
            call.
        filter (str):
            Optional. The standard list filter. Supported fields: \*
            ``display_name`` \* ``user_id``

            Example: ``display_name="abc"``, ``user_id="123"``.
        order_by (str):
            Optional. A comma-separated list of fields to order by,
            sorted in ascending order. Use "desc" after a field name for
            descending. Supported fields:

            - ``create_time``
            - ``update_time``

            Example: ``create_time desc``.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )


class ListSessionsResponse(proto.Message):
    r"""Response message for
    [SessionService.ListSessions][google.cloud.aiplatform.v1beta1.SessionService.ListSessions].

    Attributes:
        sessions (MutableSequence[google.cloud.aiplatform_v1beta1.types.Session]):
            A list of sessions matching the request.
        next_page_token (str):
            A token, which can be sent as
            [ListSessionsRequest.page_token][google.cloud.aiplatform.v1beta1.ListSessionsRequest.page_token]
            to retrieve the next page. Absence of this field indicates
            there are no subsequent pages.
    """

    @property
    def raw_page(self):
        return self

    sessions: MutableSequence[gca_session.Session] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gca_session.Session,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class UpdateSessionRequest(proto.Message):
    r"""Request message for
    [SessionService.UpdateSession][google.cloud.aiplatform.v1beta1.SessionService.UpdateSession].

    Attributes:
        session (google.cloud.aiplatform_v1beta1.types.Session):
            Required. The session to update. Format:
            ``projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/sessions/{session}``
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Optional. Field mask is used to control which
            fields get updated. If the mask is not present,
            all fields will be updated.
    """

    session: gca_session.Session = proto.Field(
        proto.MESSAGE,
        number=1,
        message=gca_session.Session,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeleteSessionRequest(proto.Message):
    r"""Request message for
    [SessionService.DeleteSession][google.cloud.aiplatform.v1beta1.SessionService.DeleteSession].

    Attributes:
        name (str):
            Required. The resource name of the session. Format:
            ``projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/sessions/{session}``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListEventsRequest(proto.Message):
    r"""Request message for
    [SessionService.ListEvents][google.cloud.aiplatform.v1beta1.SessionService.ListEvents].

    Attributes:
        parent (str):
            Required. The resource name of the session to list events
            from. Format:
            ``projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/sessions/{session}``
        page_size (int):
            Optional. The maximum number of events to
            return. The service may return fewer than this
            value. If unspecified, at most 100 events will
            be returned. These events are ordered by
            timestamp in ascending order.
        page_token (str):
            Optional. The
            [next_page_token][google.cloud.aiplatform.v1beta1.ListEventsResponse.next_page_token]
            value returned from a previous list
            [SessionService.ListEvents][google.cloud.aiplatform.v1beta1.SessionService.ListEvents]
            call.
        filter (str):
            Optional. The standard list filter. Supported fields: \*
            ``timestamp`` range (i.e.
            ``timestamp>="2025-01-31T11:30:00-04:00"`` where the
            timestamp is in RFC 3339 format)

            More detail in `AIP-160 <https://google.aip.dev/160>`__.
        order_by (str):
            Optional. A comma-separated list of fields to order by,
            sorted in ascending order. Use "desc" after a field name for
            descending. Supported fields:

            - ``timestamp``

            Example: ``timestamp desc``.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )


class ListEventsResponse(proto.Message):
    r"""Response message for
    [SessionService.ListEvents][google.cloud.aiplatform.v1beta1.SessionService.ListEvents].

    Attributes:
        session_events (MutableSequence[google.cloud.aiplatform_v1beta1.types.SessionEvent]):
            A list of events matching the request.
            Ordered by timestamp in ascending order.
        next_page_token (str):
            A token, which can be sent as
            [ListEventsRequest.page_token][google.cloud.aiplatform.v1beta1.ListEventsRequest.page_token]
            to retrieve the next page. Absence of this field indicates
            there are no subsequent pages.
    """

    @property
    def raw_page(self):
        return self

    session_events: MutableSequence[gca_session.SessionEvent] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gca_session.SessionEvent,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class AppendEventRequest(proto.Message):
    r"""Request message for
    [SessionService.AppendEvent][google.cloud.aiplatform.v1beta1.SessionService.AppendEvent].

    Attributes:
        name (str):
            Required. The resource name of the session to append event
            to. Format:
            ``projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/sessions/{session}``
        event (google.cloud.aiplatform_v1beta1.types.SessionEvent):
            Required. The event to append to the session.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    event: gca_session.SessionEvent = proto.Field(
        proto.MESSAGE,
        number=2,
        message=gca_session.SessionEvent,
    )


class AppendEventResponse(proto.Message):
    r"""Response message for
    [SessionService.AppendEvent][google.cloud.aiplatform.v1beta1.SessionService.AppendEvent].

    """


__all__ = tuple(sorted(__protobuf__.manifest))



# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Implementation in this file copied from
# https://github.com/GoogleCloudPlatform/opentelemetry-operations-go/blob/v1.8.0/detectors/gcp/faas.go

import os

from opentelemetry.resourcedetector.gcp_resource_detector import _metadata

_CLOUD_RUN_CONFIG_ENV = "K_CONFIGURATION"
_CLOUD_FUNCTION_TARGET_ENV = "FUNCTION_TARGET"
_FAAS_SERVICE_ENV = "K_SERVICE"
_FAAS_REVISION_ENV = "K_REVISION"


def on_cloud_run() -> bool:
    return _CLOUD_RUN_CONFIG_ENV in os.environ


def on_cloud_functions() -> bool:
    return _CLOUD_FUNCTION_TARGET_ENV in os.environ


def faas_name() -> str:
    """The name of the Cloud Run or Cloud Function.

    Check that on_cloud_run() or on_cloud_functions() is true before calling this, or it may
    throw exceptions.
    """
    return os.environ[_FAAS_SERVICE_ENV]


def faas_version() -> str:
    """The version/revision of the Cloud Run or Cloud Function.

    Check that on_cloud_run() or on_cloud_functions() is true before calling this, or it may
    throw exceptions.
    """
    return os.environ[_FAAS_REVISION_ENV]


def faas_instance() -> str:
    return str(_metadata.get_metadata()["instance"]["id"])


def faas_cloud_region() -> str:
    region = _metadata.get_metadata()["instance"]["region"]
    return region[region.rfind("/") + 1 :]
